# LabxDB tools

Classes and tools written in Python for [LabxDB](https://labxdb.vejnar.org).

## Download

See [tags](/../../tags) page.

## Install

```bash
pip3 install labxdb-tools
```

## License

*LabxDB* is distributed under the Mozilla Public License Version 2.0 (see /LICENSE).

Copyright (C) 2018-2022 Charles E. Vejnar
